Crate polybox_codegen

Crate polybox_codegen 

Macros for the polybox crate.

See GitHub for more information.

Derive Macros

Interface
Derives the Interface trait for an enum, allowing it to be used as a message interface in the Polybox framework.
Message
Derives the Message trait for a struct, allowing it to be used as a message in the Polybox framework.