Crate polybox_codegen
polybox_
codegen
0.0.1
All Items
Crate Items
Derive Macros
Crate
polybox_
codegen
Macros for the
polybox
crate.
See
GitHub
for more information.
Derive Macros

Interface
Derives the
Interface
trait for an enum, allowing it to be used as a message interface in the Polybox framework.
Message
Derives the
Message
trait for a struct, allowing it to be used as a message in the Polybox framework.